==> deepin-font-manager_5.9.6.orig.tar.xz: deepin-font-manager-5.9.6/translations/deepin-font-manager_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Todas as fontes</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utilizador</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritas</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Ativas</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinês</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Mono-espaçado</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 é uma família de fontes, se prosseguir, todas as fontes nela contidas serão eliminadas</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 é uma família de fontes, se prosseguir, todas as fontes nela contidas serão ativadas</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 é uma família de fontes, se prosseguir, todas as fontes nela contidas serão desativadas</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Ativar</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Desativar</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished">Aplicar a todas as famílias de fontes selecionadas</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Ficheiro corrompido</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Mesma versão instalada</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Fonte do sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Fontes</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 fonte instalada</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 fontes instaladas</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Ficheiro corrompido</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Esta fonte não estará disponível para as aplicações</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Estas fontes não estarão disponíveis para as aplicações</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>As outras %1 fontes do sistema não podem ser eliminadas</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>A fonte &quot;%1&quot; em uso não pode ser eliminada</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>As outras %1 fontes do sistema e a fonte &quot;%2&quot; em uso não podem ser eliminadas</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Tem a certeza que deseja eliminar %1 fonte(s)?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>A eliminar fontes, aguarde...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificação da fonte</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Sem fontes a instalar</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continuar</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Não deixes os teus sonhos serem sonhos</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Informação básica</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecida</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nome do postscript</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marca registada</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Gestor de Fontes</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>O Gestor de Fontes ajuda os utilizadores a instalar e a gerir fontes.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>A carregar as fontes, aguarde...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>A fonte exportada para o seu ambiente de trabalho</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 fontes exportadas para o seu ambiente de trabalho</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Falha ao exportar 1 fonte. Não há espaço suficiente em disco.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Falha ao exportar %1 fontes. Não há espaço suficiente em disco.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Adicionar fonte</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Ativar</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desativar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Adicionar às favoritas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover das favoritas</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>desativada</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>As fontes foram desativadas</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 está a ser utilizada, pelo que não a pode desativar</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Não é possível desativar as fontes do sistema e as fontes em utilização</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Não se pode desativar as fontes do sistema</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Instalar fonte</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>A verificar...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Desconhecida</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Ficheiro corrompido</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Não instalada</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Instalar fonte</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Sem resultados</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Sem fontes</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atalhos</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Página para cima</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Página para baixo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Adicionar fonte</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Adicionar às favoritas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover das favoritas</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Informação da fonte</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Inserir texto de pré-visualização</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.13.orig.tar.xz: deepin-font-manager-5.9.13/translations/deepin-font-manager_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Todas as fontes</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utilizador</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritas</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Ativas</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinês</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Mono-espaçado</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 é uma família de fontes, se prosseguir, todas as fontes nela contidas serão eliminadas</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 é uma família de fontes, se prosseguir, todas as fontes nela contidas serão ativadas</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 é uma família de fontes, se prosseguir, todas as fontes nela contidas serão desativadas</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Ativar</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Desativar</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Aplicar a todas as famílias de fontes selecionadas</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Ficheiro corrompido</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Mesma versão instalada</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Fonte do sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 fonte instalada</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 fontes instaladas</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Falha na instalação de %1 fontes. Não há espaço suficiente em disco.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Esta fonte não estará disponível para as aplicações</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Estas fontes não estarão disponíveis para as aplicações</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>As outras %1 fontes do sistema não podem ser eliminadas</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>A fonte &quot;%1&quot; em uso não pode ser eliminada</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>As outras %1 fontes do sistema e a fonte &quot;%2&quot; em uso não podem ser eliminadas</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Tem a certeza que deseja eliminar %1 fonte(s)?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>A eliminar fontes, aguarde...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificação da fonte</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Sem fontes a instalar</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continuar</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Informação básica</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecida</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nome do postscript</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marca registada</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Gestor de Fontes</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>O Gestor de Fontes ajuda os utilizadores a instalar e a gerir fontes.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>A carregar as fontes, aguarde...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>A fonte exportada para o seu ambiente de trabalho</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 fontes exportadas para o seu ambiente de trabalho</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Falha ao exportar 1 fonte. Não há espaço suficiente em disco.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Falha ao exportar %1 fontes. Não há espaço suficiente em disco.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Adicionar fonte</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Ativar</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desativar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Adicionar às favoritas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover das favoritas</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>desativada</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>As fontes foram desativadas</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 está a ser utilizada, pelo que não a pode desativar</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Não é possível desativar as fontes do sistema e as fontes em utilização</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Não se pode desativar as fontes do sistema</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Instalar fonte</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>A verificar...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Desconhecida</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Ficheiro corrompido</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Não instalada</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Instalar fonte</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Sem resultados</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Sem fontes</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atalhos</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Página para cima</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Página para baixo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Adicionar fonte</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Adicionar às favoritas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover das favoritas</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Informação da fonte</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Inserir texto de pré-visualização</translation>
    </message>
</context>
</TS>
